import type { RawBuiltins, RawHtmlPluginConfig, RawDecoratorOptions, RawMinification, RawReactOptions, RawProgressPluginConfig, RawPostCssConfig, RawPattern, RawCssModulesConfig, RawRelayConfig, RawCodeGeneration } from "@rspack/binding";
import { Optimization } from "..";
export type BuiltinsHtmlPluginConfig = Omit<RawHtmlPluginConfig, "meta"> & {
    meta?: Record<string, string | Record<string, string>>;
};
export type EmotionConfigImportMap = {
    [packageName: string]: {
        [exportName: string]: {
            canonicalImport?: [string, string];
        };
    };
};
export type EmotionConfig = boolean | {
    sourceMap?: boolean;
    autoLabel?: "never" | "dev-only" | "always";
    labelFormat?: string;
    importMap?: EmotionConfigImportMap;
};
export type CssPluginConfig = {
    modules?: Partial<RawCssModulesConfig>;
};
export type MinificationConfig = {
    passes?: number;
    dropConsole?: boolean;
    pureFuncs?: Array<string>;
    extractComments?: boolean | RegExp;
    comments?: false | "all" | "some";
    asciiOnly?: boolean;
    test?: MinifyConditions;
    exclude?: MinifyConditions;
    include?: MinifyConditions;
};
export interface Builtins {
    css?: CssPluginConfig;
    postcss?: RawPostCssConfig;
    treeShaking?: boolean | "module";
    progress?: boolean | RawProgressPluginConfig;
    react?: RawReactOptions;
    noEmitAssets?: boolean;
    define?: Record<string, string | boolean | undefined>;
    provide?: Record<string, string | string[]>;
    html?: Array<BuiltinsHtmlPluginConfig>;
    decorator?: boolean | Partial<RawDecoratorOptions>;
    minifyOptions?: MinificationConfig;
    emotion?: EmotionConfig;
    presetEnv?: Partial<RawBuiltins["presetEnv"]>;
    polyfill?: boolean;
    devFriendlySplitChunks?: boolean;
    copy?: CopyConfig;
    banner?: BannerConfigs;
    pluginImport?: PluginImportConfig[];
    relay?: RelayConfig;
    codeGeneration?: Partial<RawCodeGeneration>;
}
export type PluginImportConfig = {
    libraryName: string;
    libraryDirectory?: string;
    customName?: string;
    customStyleName?: string;
    style?: string | boolean;
    styleLibraryDirectory?: string;
    camelToDashComponentName?: boolean;
    transformToDefaultImport?: boolean;
    ignoreEsComponent?: Array<string>;
    ignoreStyleComponent?: Array<string>;
};
export type CopyConfig = {
    patterns: (string | ({
        from: string;
    } & Partial<RawPattern>))[];
};
export type BannerCondition = string | RegExp;
export type BannerConditions = BannerCondition | BannerCondition[];
export type MinifyCondition = string | RegExp;
export type MinifyConditions = MinifyCondition | MinifyCondition[];
type BannerConfig = string | {
    banner: string;
    entryOnly?: boolean;
    footer?: boolean;
    raw?: boolean;
    test?: BannerConditions;
    exclude?: BannerConditions;
    include?: BannerConditions;
};
export type BannerConfigs = BannerConfig | BannerConfig[];
export type RelayConfig = boolean | RawRelayConfig;
export type ResolvedBuiltins = Omit<RawBuiltins, "html"> & {
    html?: Array<BuiltinsHtmlPluginConfig>;
    emotion?: string;
};
export declare function resolveBuiltinsOptions(builtins: Builtins, { contextPath, production, optimization, css }: {
    contextPath: string;
    production: boolean;
    optimization: Optimization;
    css: boolean;
}): RawBuiltins;
export declare function resolveMinifyOptions(builtins: Builtins, optimization: Optimization): RawMinification | undefined;
export declare function resolveCodeGeneration(builtins: Builtins): RawCodeGeneration;
export {};
